function getEnumTypeMap(schema) {
    var _a;
    const typeMap = schema.getTypeMap();
    const result = [];
    for (const key in typeMap) {
        if (((_a = typeMap[key].astNode) === null || _a === void 0 ? void 0 : _a.kind) === 'EnumTypeDefinition') {
            result.push(typeMap[key]);
        }
    }
    return result;
}
function buildArrayDefinition(e, constArrays) {
    const upperName = e.name
        .replace(/[A-Z]/g, letter => `_${letter}`)
        .slice(1)
        .toUpperCase();
    const values = e
        .getValues()
        .map(v => `'${v.value}'`)
        .join(', ');
    if (constArrays) {
        return `export const ${upperName} = [${values}] as const;`;
    }
    else {
        return `export const ${upperName}: ${e.name}[] = [${values}];`;
    }
}
function buildImportStatement(enums, importFrom) {
    const names = Object.values(enums).map(e => e.name);
    return [`import { ${names.join(', ')} } from "${importFrom}";`];
}
export const plugin = (schema, _documents, config) => {
    const enums = getEnumTypeMap(schema);
    const content = enums.map(e => { var _a; return buildArrayDefinition(e, (_a = config.constArrays) !== null && _a !== void 0 ? _a : false); }).join('\n');
    const result = { content };
    if (config.importFrom) {
        result['prepend'] = buildImportStatement(enums, config.importFrom);
    }
    return result;
};
export default { plugin };
